from setuptools import setup, find_packages

setup(
    name='lijingli',
    version='0.0.2',
    packages = ['lijingli'],
    author='JIa Junjie',
    install_requires=[
        "minepy==1.2.6"
    ],
    python_requires='>=3.7'
)